@@ -12,8 +12,11 @@ Number = Union[Decimal, float, int]
 
 @dataclass
 class Length:
+    """
+    https://developer.mozilla.org/en-US/docs/Web/SVG/Content_type#length
+    """
     value: Number
-    unit: Literal["em", "ex", "px", "pt", "pc", "cm", "mm", "in"]
+    unit: Literal["em", "ex", "px", "pt", "pc", "cm", "mm", "in", "%"]
 
     def __str__(self) -> str:
         return f"{self.value}{self.unit}"
@@ -21,6 +24,9 @@ class Length:
 
 @dataclass
 class PreserveAspectRatio:
+    """
+    https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/preserveAspectRatio
+    """
     alignment: Literal[
         "none",
         "xMinYMin",
@@ -41,10 +47,13 @@ class PreserveAspectRatio:
 
 @dataclass
 class ViewBoxSpec:
-    min_x: int
-    min_y: int
-    width: int
-    height: int
+    """
+    https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/viewBox
+    """
+    min_x: Number
+    min_y: Number
+    width: Number
+    height: Number
 
     def __str__(self) -> str:
         return f"{self.min_x} {self.min_y} {self.width} {self.height}"
